==> maven-war-plugin_3.3.2.orig.tar.xz: maven-war-plugin-maven-war-plugin-3.3.2/src/test/java/org/apache/maven/plugins/war/stub/EJBClientArtifactStub.java <==
package org.apache.maven.plugins.war.stub;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.maven.artifact.handler.ArtifactHandler;
import org.apache.maven.artifact.handler.DefaultArtifactHandler;

import java.io.File;

public class EJBClientArtifactStub
    extends AbstractArtifactStub
{
    protected String groupId;

    public EJBClientArtifactStub( String _basedir )
    {
        super( _basedir );
    }

    public void setGroupId( String id )
    {
        groupId = id;
    }

    public String getGroupId()
    {
        if ( groupId != null )
        {
            return groupId;
        }
        else
        {
            return "org.sample.ejb";
        }
    }

    public String getType()
    {
        return "ejb-client";
    }

    public String getClassifier()
    {
        return "client";
    }

    public String getArtifactId()
    {
        return "ejbclientartifact";
    }

    public File getFile()
    {
        return new File( basedir, "/target/test-classes/unit/sample_wars/ejbclient.jar" );
    }

    public ArtifactHandler getArtifactHandler()
    {
        return new DefaultArtifactHandler()
        {
            public String getExtension()
            {
                return "jar";
            }
        };
    }
}

==> maven-war-plugin_3.4.0.orig.tar.xz: maven-war-plugin-maven-war-plugin-3.4.0/src/test/java/org/apache/maven/plugins/war/stub/EJBClientArtifactStub.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.plugins.war.stub;

import java.io.File;

import org.apache.maven.artifact.handler.ArtifactHandler;
import org.apache.maven.artifact.handler.DefaultArtifactHandler;

public class EJBClientArtifactStub extends AbstractArtifactStub {
    protected String groupId;

    public EJBClientArtifactStub(String _basedir) {
        super(_basedir);
    }

    public void setGroupId(String id) {
        groupId = id;
    }

    public String getGroupId() {
        if (groupId != null) {
            return groupId;
        } else {
            return "org.sample.ejb";
        }
    }

    public String getType() {
        return "ejb-client";
    }

    public String getClassifier() {
        return "client";
    }

    public String getArtifactId() {
        return "ejbclientartifact";
    }

    public File getFile() {
        return new File(basedir, "/target/test-classes/unit/sample_wars/ejbclient.jar");
    }

    public ArtifactHandler getArtifactHandler() {
        return new DefaultArtifactHandler() {
            public String getExtension() {
                return "jar";
            }
        };
    }
}
